import type { ProxyConfiguration } from './ProxyConfiguration';
import type { SdkVerbosity } from './SdkVerbosity';
import { TrackingConsent } from './TrackingConsent';
/**
 * The SDK configuration class.
 * It will be used to configure the SDK functionality at initialization.
 */
export declare class DdSdkReactNativeConfiguration {
    readonly clientToken: string;
    readonly env: string;
    readonly applicationId: string;
    readonly trackInteractions: boolean;
    readonly trackResources: boolean;
    readonly trackErrors: boolean;
    readonly trackingConsent: TrackingConsent;
    nativeCrashReportEnabled: boolean;
    /**
     * @deprecated `sampleRate` has been replaced by `sessionSamplingRate` to avoid confusion with `resourceTracingSamplingRate` and will be removed in a future release.
     */
    sampleRate?: number;
    /**
     * Percentage of sampled RUM sessions. Range `0`-`100`.
     */
    sessionSamplingRate: number;
    /**
     * Percentage of tracing integrations for network calls between your app and your backend. Range `0`-`100`.
     */
    resourceTracingSamplingRate: number;
    site: string;
    verbosity: SdkVerbosity | undefined;
    nativeViewTracking: boolean;
    proxyConfig?: ProxyConfiguration;
    serviceName?: string;
    firstPartyHosts: string[];
    /**
     * Overrides the reported version of the app.
     * Accepted characters are alphanumerics and `_`, `-`, `:`, `.`, `/`.
     * Other special characters are converted to underscores.
     *
     * See https://docs.datadoghq.com/getting_started/tagging/#define-tags for more information on the format.
     *
     * Make sure you set it correctly, as it will have to match the one specified during the upload of your source maps and other mapping files.
     */
    version?: string;
    /**
     * Add a suffix to the reported version of the app.
     * Accepted characters are alphanumerics and `_`, `-`, `:`, `.`, `/`.
     * Other special characters are converted to underscores.
     *
     * See https://docs.datadoghq.com/getting_started/tagging/#define-tags for more information on the format.
     *
     * A dash (`-`) will be automatically added between the version and the suffix
     */
    versionSuffix?: string;
    additionalConfig: {
        [k: string]: any;
    };
    constructor(clientToken: string, env: string, applicationId: string, trackInteractions?: boolean, trackResources?: boolean, trackErrors?: boolean, trackingConsent?: TrackingConsent);
}
